AuthenticatorMode

Enum AuthenticatorMode 

pub enum AuthenticatorMode {
    NoCryptography(AuthenticationProperties),
    AttemptList(Vec<AuthenticatorMode>),
}
Available on crate feature client only.
Modes for exchanging keys between client and server.

This enum represents the different methods by which keys (e.g., Diffie-Hellman) are exchanged for securing communication. Although communication is primarily done using UDP, if a TCP or TLS authenticator is used, the Diffie-Hellman keys are exchanged accordingly. These keys are then used for encrypting data throughout the UDP connection.

Variants



NoCryptography(AuthenticationProperties)

No cryptographic exchange, using only the provided authentication properties.



AttemptList(Vec<AuthenticatorMode>)

Attempts a list of authenticator modes in sequence until one succeeds.