Module packets

Module packets 

Sets of data that are transferred over the communication.

Re-exports

pub extern crate lyanne_derive;

Re-exports

pub use bincode;sd_bincode

Structs

ClientTickEndPacket
Packet sent by the client in every message.
DeserializedMessageMap
Deserialized packets stored in a map, by their IDs.
DeserializedPacket
Represents a deserialized packet.
EmptyPacket
Empty packet, useful to send an empty message.
PacketRegistry
Registry holder for the Packets.
SerializedPacket
Represents a packet serialized to bytes.
SerializedPacketList
List of serialized packets.
ServerTickEndPacket
Packet sent by the server in every message.

Traits

Packet
Set of data used for exchanging information.

Type Aliases

PacketId
PacketToDowncast

Derive Macros

Packetsd_bincode