Sets of data that are transferred over the communication.
Re-exports
pub extern crate lyanne_derive;
Re-exports
pub use bincode;sd_bincode
Structs
- Client
Tick EndPacket - Packet sent by the client in every message.
- Deserialized
Message Map - Deserialized packets stored in a map, by their IDs.
- Deserialized
Packet - Represents a deserialized packet.
- Empty
Packet - Empty packet, useful to send an empty message.
- Packet
Registry - Registry holder for the Packets.
- Serialized
Packet - Represents a packet serialized to bytes.
- Serialized
Packet List - List of serialized packets.
- Server
Tick EndPacket - Packet sent by the server in every message.
Traits
- Packet
- Set of data used for exchanging information.
Type Aliases
Derive Macros
- Packet
sd_bincode