pub enum ClientDisconnectReason {
PendingMessageConfirmationTimeout,
MessageReceiveTimeout,
WriteUnlockTimeout,
ByteSendError(Error),
ManualDisconnect,
DisconnectRequest(DeserializedMessage),
}Available on crate feature
server only.Expand description
Possible reasons to be disconnected from some client.
Used after the client was already disconnected.
Variants
PendingMessageConfirmationTimeout
Client was disconnected due to a timeout waiting for message confirmation.
MessageReceiveTimeout
Client was disconnected because it did not receive messages within the expected time frame.
WriteUnlockTimeout
Client was disconnected due to a timeout while trying to acquire a write lock.
ByteSendError(Error)
Client was disconnected because of an error while sending bytes.
ManualDisconnect
Client was manually disconnected.
DisconnectRequest(DeserializedMessage)
Client disconnected itself.